Coverage report

File | class | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | --- | ---
src\attipy\__init__.py | (no class) | 2 | 0 | 0 | 0 | 0 | 100%
src\attipy\_attitude.py | AttitudeBase | 0 | 0 | 1 | 0 | 0 | 100%
src\attipy\_attitude.py | UnitQuaternion | 2 | 0 | 0 | 0 | 0 | 100%
src\attipy\_attitude.py | AttitudeMatrix | 8 | 2 | 0 | 4 | 2 | 67%
src\attipy\_attitude.py | (no class) | 19 | 0 | 0 | 0 | 0 | 100%
src\attipy\_transforms.py | (no class) | 29 | 24 | 0 | 0 | 0 | 17%
src\attipy\_vectorops.py | (no class) | 6 | 1 | 0 | 0 | 0 | 83%
Total |  | 66 | 27 | 1 | 4 | 2 | 59%

No items found using the specified filter.